aboutsummaryrefslogtreecommitdiff
path: root/build
diff options
context:
space:
mode:
authormat <github@matdoes.dev>2021-05-31 20:51:45 -0500
committermat <github@matdoes.dev>2021-05-31 20:51:45 -0500
commit18ea9e67c963690c4f62b7376ce289cc78bf2daa (patch)
tree2c29fe15a150298f0d8249863b735f612ed9c359 /build
parentf1e85074ce32f62a7b44d5bd6c8399d99f2368c5 (diff)
downloadskyblock-api-18ea9e67c963690c4f62b7376ce289cc78bf2daa.tar.gz
skyblock-api-18ea9e67c963690c4f62b7376ce289cc78bf2daa.tar.bz2
skyblock-api-18ea9e67c963690c4f62b7376ce289cc78bf2daa.zip
decrease basicPlayerCache maxAge more
Diffstat (limited to 'build')
-rw-r--r--build/hypixelCached.js4
1 files changed, 2 insertions, 2 deletions
diff --git a/build/hypixelCached.js b/build/hypixelCached.js
index cb078f2..8da20e3 100644
--- a/build/hypixelCached.js
+++ b/build/hypixelCached.js
@@ -51,10 +51,10 @@ exports.playerCache = new node_cache_1.default({
checkperiod: 10,
useClones: true,
});
// cache "basic players" (players without profiles) for 30 minutes
exports.basicPlayerCache = new lru_cache_1.default({
max: 10000,
- maxAge: 60 * 30 * 1000,
+ maxAge: 60 * 20 * 1000,
});
exports.profileCache = new node_cache_1.default({
stdTTL: 30,
@@ -51,10 +51,10 @@ exports.playerCache = new node_cache_1.default({
useClones: true,
});
-// cache "basic players" (players without profiles) for 30 minutes
+// cache "basic players" (players without profiles) for 20 minutes
exports.basicPlayerCache = new lru_cache_1.default({
max: 10000,